@@ -1,17 +1,17 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Common\DataFixtures\Purger;
 
 use Doctrine\ODM\MongoDB\DocumentManager;
 
 /**
  * Class responsible for purging databases of data before reloading data fixtures.
- *
- * @author Jonathan H. Wage <jonwage@gmail.com>
  */
 class MongoDBPurger implements PurgerInterface
 {
-    /** DocumentManager instance used for persistence. */
+    /** @var DocumentManager|null */
     private $dm;
 
     /**
@@ -19,15 +19,13 @@ class MongoDBPurger implements PurgerInterface
      *
      * @param DocumentManager $dm DocumentManager instance used for persistence.
      */
-    public function __construct(DocumentManager $dm = null)
+    public function __construct(?DocumentManager $dm = null)
     {
         $this->dm = $dm;
     }
 
     /**
      * Set the DocumentManager instance this purger instance should use.
-     *
-     * @param DocumentManager $dm
      */
     public function setDocumentManager(DocumentManager $dm)
     {
@@ -37,7 +35,7 @@ class MongoDBPurger implements PurgerInterface
     /**
      * Retrieve the DocumentManager instance this purger instance is using.
      *
-     * @return \Doctrine\ODM\MongoDB\DocumentManager
+     * @return DocumentManager
      */
     public function getObjectManager()
     {
@@ -49,9 +47,11 @@ class MongoDBPurger implements PurgerInterface
     {
         $metadatas = $this->dm->getMetadataFactory()->getAllMetadata();
         foreach ($metadatas as $metadata) {
-            if ( ! $metadata->isMappedSuperclass) {
-                $this->dm->getDocumentCollection($metadata->name)->drop();
+            if ($metadata->isMappedSuperclass) {
+                continue;
             }
+
+            $this->dm->getDocumentCollection($metadata->name)->drop();
         }
         $this->dm->getSchemaManager()->ensureIndexes();
     }
