@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Common\DataFixtures\Purger;
 
 use Doctrine\ODM\PHPCR\DocumentManager;
@@ -8,17 +10,13 @@ use PHPCR\Util\NodeHelper;
 
 /**
  * Class responsible for purging databases of data before reloading data fixtures.
- *
- * @author Daniel Barsotti <daniel.barsotti@liip.ch>
  */
 class PHPCRPurger implements PurgerInterface
 {
-    /**
-     * @var DocumentManagerInterface
-     */
+    /** @var DocumentManagerInterface */
     private $dm;
 
-    public function __construct(DocumentManagerInterface $dm = null)
+    public function __construct(?DocumentManagerInterface $dm = null)
     {
         $this->dm = $dm;
     }
